'use strict';

var _config = require('./config');

var _windowHolder = require('./window-holder');

var _windowHolder2 = _interopRequireDefault(_windowHolder);

var _electron = require('electron');

var _constants = require('../shared/constants');

var _shortcuts = require('./shortcuts');

var registerShortcuts = _interopRequireWildcard(_shortcuts);

var _utils = require('./utils');

var _logger = require('./logger');

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

if (process.env.NODE_ENV !== 'development') {
  process.env.NODE_ENV = 'production';
}

process.title = 'record-desktop';
process.on('unhandledRejection', function (err) {
  (0, _logger.notify)(err.stack || err);
});

var windowHolder = void 0;

_electron.app.on('ready', function () {
  windowHolder = new _windowHolder2.default(_electron.app);

  _config.eventEmitter.on(_constants.NEW_FILE, function () {
    windowHolder.updateTrayMenu();
    windowHolder.sendWebContents(_constants.NEW_FILE);
  });

  _config.eventEmitter.on(_constants.SET_APP_ICON, function (isRecording) {
    windowHolder.setAppIcon(isRecording);
  });

  _electron.ipcMain.on(_constants.OPEN_FILE, function (event, data) {
    (0, _utils.openFile)(data);
  });

  _electron.ipcMain.on(_constants.COPY_TO_CLIPBOARD, function (event, data) {
    (0, _utils.copyToClipboard)(data);
  });

  _electron.ipcMain.on(_constants.DELETE_FILE, function (event, data) {
    (0, _utils.deleteFile)(data);
    windowHolder.updateTrayMenu();
  });

  _electron.ipcMain.on(_constants.UPLOAD, function (event, data) {
    (0, _utils.uploadFile)(data);
  });

  registerShortcuts.registerAll();
});

_electron.app.on('will-quit', function () {
  if (windowHolder) {
    windowHolder.destroy();
    windowHolder = null;
  }

  _electron.globalShortcut.unregisterAll();
});